pub struct CheckpointFileReader { /* private fields */ }Expand description
Manager for reading checkpoint files directly from filesystem.
Implementations
Sourceimpl CheckpointFileReader
impl CheckpointFileReader
Sourcepub fn new(dir: impl Into<PathBuf>) -> Self
pub fn new(dir: impl Into<PathBuf>) -> Self
Create a new checkpoint file reader for the given directory.
Sourcepub fn read_latest_checkpoint(&self, phase: SyncPhase) -> Result<CheckpointFile>
pub fn read_latest_checkpoint(&self, phase: SyncPhase) -> Result<CheckpointFile>
Read the latest checkpoint file for a given phase.
Sourcepub fn read_checkpoint<C: Checkpoint>(&self, phase: SyncPhase) -> Result<C>
pub fn read_checkpoint<C: Checkpoint>(&self, phase: SyncPhase) -> Result<C>
Read and parse checkpoint into database-specific type.