FlattenId

Struct FlattenId 

pub struct FlattenId {
    pub separator: String,
}
Rewrite Value::Array record IDs to Text joined with Self::separator.

Scalar IDs are left unchanged. Relation edge IDs are also flattened when they are Arrays (endpoint Thing refs are flattened the same way so links stay consistent if a source emitted Array endpoint IDs).

Fields

separator: String

Joiner between composite key parts (default :).

Implementations

Source

impl FlattenId

pub fn new(separator: impl Into<String>) -> Self

Create with an explicit separator.