Store checkpoints on the filesystem. Filesystem checkpoint storage for surreal-sync.
Provides [FilesystemStore] and helpers for reading checkpoint files
from a directory. The storage-agnostic API lives in sync-core.
Structs
- Checkpoint
File - Storage-agnostic checkpoint file wrapper.
- Checkpoint
File Reader - Manager for reading checkpoint files directly from filesystem.
- CheckpointID
- Checkpoint identifier for storage
- Filesystem
Store - Filesystem implementation of CheckpointStore trait.
- Null
Store - A no-op checkpoint store for when checkpoint storage is disabled.
- Stored
Checkpoint - Checkpoint data stored in backend
- Sync
Manager - Manager for handling sync operations with checkpoint tracking.
Enums
- Sync
Phase - Represents different phases of the synchronization process.
Traits
- Checkpoint
- Trait that database-specific checkpoints must implement.
- Checkpoint
Store - Trait for checkpoint storage operations.
Functions
- get_
checkpoint_ for_ phase - Read a checkpoint file for a specific phase from a directory.
- get_
first_ checkpoint_ from_ dir - Read the first checkpoint file from a directory containing checkpoint files.
Type Aliases
- Null
Sync Manager - Type alias for SyncManager with disabled checkpointing.