pub struct PositionedChange<P> {
pub change: Change,
pub position: P,
}Expand description
A CDC / incremental row event plus the source position to advance after sink success.
Prefer PositionedEvent when the feed may also emit relation changes.
Fields
change: ChangeUniversal change to transform and apply.
position: PSource position associated with this change (checkpoint candidate).
Implementations
Sourceimpl<P> PositionedChange<P>
impl<P> PositionedChange<P>
Sourcepub fn into_event(self) -> PositionedEvent<P>
pub fn into_event(self) -> PositionedEvent<P>
Convert to the unified PositionedEvent form.